Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Serverless Application Repository.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for AWS Serverless Application Repository - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for AWS Serverless Application Repository

AWS Serverless Application Repository (service prefix: `serverlessrepo` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

Topics

- Actions Defined by AWS Serverless Application Repository
- Resource Types Defined by AWS Serverless Application Repository
- Condition Keys for AWS Serverless Application Repository

## Actions Defined by AWS Serverless Application Repository

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateApplication | Creates an application, optionally including an AWS SAM file to create the first application version in the same call. | Write |  |  |
CreateApplicationVersion | Creates an application version. | Write | applications* |  |
CreateCloudFormationChangeSet | Creates an AWS CloudFormation ChangeSet for the given application. | Write | applications* |  |
| serverlessrepo:applicationType |
CreateCloudFormationTemplate | Creates an AWS CloudFormation template | Write | applications* |  |
| serverlessrepo:applicationType |
DeleteApplication | Deletes the specified application | Write | applications* |  |
GetApplication | Gets the specified application. | Read | applications* |  |
| serverlessrepo:applicationType |
GetApplicationPolicy | Gets the policy for the specified application. | Read | applications* |  |
GetCloudFormationTemplate | Gets the specified AWS CloudFormation template | Read | applications* |  |
ListApplicationDependencies | Retrieves the list of applications nested in the containing application | List | applications* |  |
| serverlessrepo:applicationType |
ListApplicationVersions | Lists versions for the specified application owned by the requester. | List | applications* |  |
| serverlessrepo:applicationType |
ListApplications | Lists applications owned by the requester. | List |  |  |
PutApplicationPolicy | Puts the policy for the specified application. | Write | applications* |  |
SearchApplications | Gets all applications authorized for this user | Read |  | serverlessrepo:applicationType |
UnshareApplication | Unshares the specified application | Write | applications* |  |
UpdateApplication | Updates meta-data of the application | Write | applications* |  |

## Resource Types Defined by AWS Serverless Application Repository

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
applications | `arn:$ { Partition}:serverlessrepo:$ { Region}:$ { Account}:applications/$ { ResourceId}` |

## Condition Keys for AWS Serverless Application Repository

AWS Serverless Application Repository defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
serverlessrepo:applicationType | Application type | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.